@@ -5,7 +5,17 @@ Module: taz
 
 Trivial Azure API
 
+Subpackages:
+    - taz[blob]
+    - taz[dev]
+    - taz[dls]
+    - taz[aci]
+    - taz[auth]
+
+to include in requirements.txt use notation: taz[blob,dls] for example
+
 Submodules:
+    - taz.keyvault
     - taz.auth
     - taz.acr
     - taz.aci
