@@ -226,11 +226,36 @@ class Blob:
         """
         self.client.delete_blob()
 
+    def add_metadata(self, metadata):
+        old_metadata = self.get_metadata()
+        metadata.update(old_metadata)
+        self.set_metadata(metadata)
+        return self.get_metadata()
+
+    def set_metadata(self, metadata: dict):
+        """replace blob metadata
+
+        :param metadata: metadata (if None, reset)
+        :type metadata: dict
+        """
+        self.client.set_blob_metadata(metadata)
+        return self.get_metadata()
+
+    def get_metadata(self):
+        return self.get_properties().metadata
+
     def get_properties(self):
         """get all blob properties
 
         :return: blob proberties object
         :rtype: azure.storage.blob.BlobProperties
+            BloProperties fields:
+            - name
+            - container
+            - metadata
+            - size
+            - last_modified
+            (see Azure documentation for further details) 
         """
         return self.client.get_blob_properties()
 
