@@ -15,6 +15,9 @@ class AciViewTests(unittest.TestCase):
         self.container_group = SimpleContainerGroup(
             cfg.aci["container_group_name"], cfg.aci["resource_group"],
         )
+        self.logs_sas_key = cfg.aci["logs_sas_key"]
+        self.logs_container = cfg.aci["logs_container"]
+        self.logs_storage_account = cfg.aci["logs_storage_account"]
 
     def test_10_display(self):
         self.assertTrue(self.container_group is not None)
@@ -28,6 +31,15 @@ class AciViewTests(unittest.TestCase):
     def test_20_list_logs(self):
         print(self.container_group.list_logs())
 
+    def test_30_save_logs(self):
+        print(
+            self.container_group.save_logs(
+                self.logs_container,
+                sas_key=self.logs_sas_key,
+                storage_account_name=self.logs_storage_account,
+            )
+        )
+
 
 if __name__ == "__main__":
     sys.argv.append("-v")
