@@ -34,7 +34,7 @@ class BlobTests(unittest.TestCase):
         self.test_010_get_storage_account()
         self.container = Container(self.storage_account, self.container_name)
 
-    def test_013_get_container_properties(self):
+    def test_015_get_container_properties(self):
         self.test_010_get_storage_account()
         self.container = Container(self.storage_account, self.container_name)
         print(self.container.get_properties())
@@ -115,15 +115,25 @@ class BlobTests(unittest.TestCase):
         print(data)
         self.assertTrue(data is not None)
 
-    def test_075_blob_download(self):
+    def test_072_blob_download(self):
         self.test_040_get_blob()
         print(self.blob.name)
         print(self.localpath)
         self.blob.download(self.localpath)
 
-    def test_076_blob_get_properties(self):
+    def test_074_blob_set_metadata(self):
         self.test_040_get_blob()
-        print(type(self.blob.get_properties()))
+        self.blob.set_metadata({"key1": "val1", "key2": "val2"})
+
+    def test_075_blob_add_metadata(self):
+        self.test_040_get_blob()
+        print(self.blob.add_metadata({"key3": "val3"}))
+
+    def test_076_blob_get_metadata(self):
+        self.test_040_get_blob()
+        metadata = self.blob.get_metadata()
+        print(metadata)
+        self.assertEqual(metadata["key2"], "val2")
 
     def test_077_blob_get_size(self):
         self.test_040_get_blob()
@@ -164,7 +174,7 @@ class BlobTests(unittest.TestCase):
         self.test_044_get_blob_by_sas_key()
         self.sas_key_blob.delete()
 
-    # WARNING: do not delete conatiner for aci logs save test to pass
+    # WARNING: do not delete container for aci logs save test to pass
     #
     # def test_140_container_delete(self):
     #     self.storage_account = StorageAccount(
